# Generated by roxygen2: do not edit by hand

S3method(assumptions,exp_series_md_c1_c2_c3)
S3method(assumptions,wei_series_homogeneous_md_c1_c2_c3)
S3method(assumptions,wei_series_md_c1_c2_c3)
S3method(cause_probability,exp_series_md_c1_c2_c3)
S3method(cause_probability,series_md)
S3method(component_hazard,exp_series_md_c1_c2_c3)
S3method(component_hazard,wei_series_homogeneous_md_c1_c2_c3)
S3method(component_hazard,wei_series_md_c1_c2_c3)
S3method(conditional_cause_probability,exp_series_md_c1_c2_c3)
S3method(conditional_cause_probability,series_md)
S3method(hess_loglik,exp_series_md_c1_c2_c3)
S3method(hess_loglik,wei_series_homogeneous_md_c1_c2_c3)
S3method(hess_loglik,wei_series_md_c1_c2_c3)
S3method(loglik,exp_series_md_c1_c2_c3)
S3method(loglik,wei_series_homogeneous_md_c1_c2_c3)
S3method(loglik,wei_series_md_c1_c2_c3)
S3method(mean,exp_series)
S3method(ncomponents,exp_series_md_c1_c2_c3)
S3method(ncomponents,wei_series_homogeneous_md_c1_c2_c3)
S3method(ncomponents,wei_series_md_c1_c2_c3)
S3method(rdata,exp_series_md_c1_c2_c3)
S3method(rdata,wei_series_homogeneous_md_c1_c2_c3)
S3method(rdata,wei_series_md_c1_c2_c3)
S3method(score,exp_series_md_c1_c2_c3)
S3method(score,wei_series_homogeneous_md_c1_c2_c3)
S3method(score,wei_series_md_c1_c2_c3)
export(assumptions)
export(cause_probability)
export(component_hazard)
export(conditional_cause_probability)
export(dexp_series)
export(exp_series_md_c1_c2_c3)
export(fim)
export(fit)
export(hazard_exp_series)
export(hess_loglik)
export(integrate_hazard)
export(loglik)
export(md_bernoulli_cand_c1_c2_c3)
export(md_boolean_matrix_to_charsets)
export(md_cand_sampler)
export(md_encode_matrix)
export(md_series_lifetime_right_censoring)
export(ncomponents)
export(observe_left_censor)
export(observe_mixture)
export(observe_periodic)
export(observe_right_censor)
export(pexp_series)
export(qcomp)
export(qexp_series)
export(rcomp)
export(rdata)
export(rexp_series)
export(score)
export(surv.exp_series)
export(wei_series_homogeneous_md_c1_c2_c3)
export(wei_series_md_c1_c2_c3)
export(wei_series_system_scale)
importFrom(generics,fit)
importFrom(likelihood.model,assumptions)
importFrom(likelihood.model,fim)
importFrom(likelihood.model,hess_loglik)
importFrom(likelihood.model,loglik)
importFrom(likelihood.model,rdata)
importFrom(likelihood.model,score)
importFrom(numDeriv,grad)
importFrom(numDeriv,jacobian)
importFrom(stats,dexp)
importFrom(stats,integrate)
importFrom(stats,pexp)
importFrom(stats,qexp)
importFrom(stats,rexp)
importFrom(stats,runif)
importFrom(stats,rweibull)
